==> jc-1.4.0.tar.gz: polyglot/frontend/SpawnPass.h <==
// public class polyglot.frontend.SpawnPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 4533ef48cc31efee polyglot_frontend_SpawnPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_SpawnPass_H_
#define _JC_polyglot_frontend_SpawnPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SpawnPass$sub_refs	_jc_polyglot_frontend_SpawnPass$sub_refs;
typedef struct _jc_polyglot_frontend_SpawnPass$sub_nonrefs	_jc_polyglot_frontend_SpawnPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SpawnPass$refs	_jc_polyglot_frontend_SpawnPass$refs;
typedef struct _jc_polyglot_frontend_SpawnPass$nonrefs	_jc_polyglot_frontend_SpawnPass$nonrefs;
typedef struct _jc_polyglot_frontend_SpawnPass$object	_jc_polyglot_frontend_SpawnPass$object;

typedef const struct _jc_polyglot_frontend_SpawnPass$vmethods	_jc_polyglot_frontend_SpawnPass$vmethods;
typedef const struct _jc_polyglot_frontend_SpawnPass$vtable	_jc_polyglot_frontend_SpawnPass$vtable;
typedef const struct _jc_polyglot_frontend_SpawnPass$vtype	_jc_polyglot_frontend_SpawnPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_SpawnPass$method$_init$2a107905fec43edc(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Pass__24ID$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_SpawnPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SpawnPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_SpawnPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_SpawnPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_SpawnPass$vmethods	polyglot_frontend_SpawnPass;
};

// Vtype
struct _jc_polyglot_frontend_SpawnPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SpawnPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SpawnPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_frontend_Pass__24ID$object	*begin;
	struct _jc_polyglot_frontend_Pass__24ID$object	*end;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SpawnPass$refs {
    _jc_polyglot_frontend_SpawnPass$sub_refs	polyglot_frontend_SpawnPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SpawnPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SpawnPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_SpawnPass$sub_nonrefs	polyglot_frontend_SpawnPass;
};

// Object instance structure
struct _jc_polyglot_frontend_SpawnPass$object {
	_jc_polyglot_frontend_SpawnPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SpawnPass$vtype	*vtype;
	_jc_polyglot_frontend_SpawnPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SpawnPass$vtype _jc_polyglot_frontend_SpawnPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SpawnPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SpawnPass$class_object;

#endif	/* _JC_polyglot_frontend_SpawnPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/SpawnPass.h <==
// public class polyglot.frontend.SpawnPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 4533ef48cc31efee polyglot_frontend_SpawnPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_SpawnPass_H_
#define _JC_polyglot_frontend_SpawnPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SpawnPass$sub_refs	_jc_polyglot_frontend_SpawnPass$sub_refs;
typedef struct _jc_polyglot_frontend_SpawnPass$sub_nonrefs	_jc_polyglot_frontend_SpawnPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SpawnPass$refs	_jc_polyglot_frontend_SpawnPass$refs;
typedef struct _jc_polyglot_frontend_SpawnPass$nonrefs	_jc_polyglot_frontend_SpawnPass$nonrefs;
typedef struct _jc_polyglot_frontend_SpawnPass$object	_jc_polyglot_frontend_SpawnPass$object;

typedef const struct _jc_polyglot_frontend_SpawnPass$vmethods	_jc_polyglot_frontend_SpawnPass$vmethods;
typedef const struct _jc_polyglot_frontend_SpawnPass$vtable	_jc_polyglot_frontend_SpawnPass$vtable;
typedef const struct _jc_polyglot_frontend_SpawnPass$vtype	_jc_polyglot_frontend_SpawnPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_SpawnPass$method$_init$2a107905fec43edc(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Pass__24ID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_SpawnPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SpawnPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_SpawnPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_SpawnPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_SpawnPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_SpawnPass$vmethods	polyglot_frontend_SpawnPass;
};

// Vtype
struct _jc_polyglot_frontend_SpawnPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SpawnPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SpawnPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_frontend_Pass__24ID$object	*begin;
	struct _jc_polyglot_frontend_Pass__24ID$object	*end;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SpawnPass$refs {
    _jc_polyglot_frontend_SpawnPass$sub_refs	polyglot_frontend_SpawnPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SpawnPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SpawnPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_SpawnPass$sub_nonrefs	polyglot_frontend_SpawnPass;
};

// Object instance structure
struct _jc_polyglot_frontend_SpawnPass$object {
	_jc_polyglot_frontend_SpawnPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SpawnPass$vtype	*vtype;
	_jc_polyglot_frontend_SpawnPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SpawnPass$vtype _jc_polyglot_frontend_SpawnPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SpawnPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SpawnPass$class_object;

#endif	/* _JC_polyglot_frontend_SpawnPass_H_ */
